@@ -1,3 +1,3 @@
 from .stats import PasswordStats
 from .policy import PasswordPolicy
-import tests
+from . import tests
